'' =================================================================================================
''
''   File....... jm_blinker2_timer.spin
''   Purpose.... Simple blinker demo using waitcnt in main loop
''   Author..... Jon "JonnyMac" McPhalen
''               Copyright (c) 2014 Jon McPhalen
''               -- see below for terms of use
''   E-mail..... jon@jonmcphalen.com
''   Started.... 
''   Updated.... 12 APR 2015 
''
'' =================================================================================================


con { timing }

  _clkmode = xtal1 + pll16x
  _xinfreq = 5_000_000                                           ' use 5MHz crystal

  CLK_FREQ = (_clkmode >> 6) * _xinfreq                          ' system freq as a constant
  MS_001   = CLK_FREQ / 1_000                                    ' ticks in 1ms
  US_001   = CLK_FREQ / 1_000_000                                ' ticks in 1us


con { io pins }

  RX1     = 31                                                   ' programming / terminal
  TX1     = 30                                                    
                                                                  
  SDA     = 29                                                   ' eeprom / i2c
  SCL     = 28                                                    
                                                                  
  LED_27  = 27                                                   ' leds on audio outputs
  LED_26  = 26                                                    
                                                                  
  AUD_RT  = 27                                                   ' audio (d/a) outputs
  AUD_LF  = 26                                                    
                                                                  
  SD_CS   = 25                                                   ' usd card
  SD_DI   = 24                                                    
  SD_CLK  = 23                                                    
  SD_DO   = 22                                                    
                                                                  
  ADC_CS  = 21                                                   ' adc input
  ADC_CLK = 20                                                    
  ADC_DO  = 19                                                    
  ADC_DI  = 18                                                    
                                                                  
  SVO_6   = 17                                                   ' servo headers
  SVO_5   = 16                                                    

  SVO_4   = 15
  SVO_3   = 14

  SVO_2   = 13
  SVO_1   = 12
    

obj

  io       : "jm_io"                                             ' basic io control
  led26tmr : "jm_time"                                           ' timer for LED on P26
  led27tmr : "jm_time"                                           ' timer for LED on P27


pub main

  io.low(LED_26)                                                 ' initialize LED pin
  led26tmr.start                                                 ' start the timer

  io.low(LED_27)
  led27tmr.start

  repeat
    update_p26
    update_p27


pub update_p26

  if (led26tmr.millis => 125)                                    ' period expired
    led26tmr.adjust(-125)                                        ' yes, back up
    io.toggle(LED_26)                                            ' toggle LED


pub update_p27

  if (outa[LED_27] == 1)                                         ' LED on?
    if (led27tmr.millis => 333)                                  ' on period expired
      led27tmr.adjust(-333)                                      ' back up timer
      io.low(LED_27)                                             ' set to off
  else
    if (led27tmr.millis => 667)                                  ' off timer expired?
      led27tmr.adjust(-667)                                      ' back up timer
      io.high(LED_27)                                            ' set to on


dat { license }

{{

  Terms of Use: MIT License

  Permission is hereby granted, free of charge, to any person obtaining a copy of this
  software and associated documentation files (the "Software"), to deal in the Software
  without restriction, including without limitation the rights to use, copy, modify,
  merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
  permit persons to whom the Software is furnished to do so, subject to the following
  conditions:

  The above copyright notice and this permission notice shall be included in all copies
  or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
  INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
  PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
  HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
  CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
  OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

}}